@@ -4,16 +4,6 @@ import typing
 import dacite
 
 
-@dataclasses.dataclass
-class Config:
-    apiUrl: str = 'http://localhost:4200'
-    ciBuildId: str = None
-    branchName: str = None
-    project: str = None
-    apiKey: str = None
-    enableSoftAssert: bool = False
-
-
 @dataclasses.dataclass
 class IgnoreArea:
     x: int = None
